@@ -151,6 +151,12 @@ class GeneratorTestCase(base.BaseTestCase):
         'list_opt': cfg.ListOpt('list_opt',
                                 default=['1', '2', '3'],
                                 help='a list'),
+        'list_opt_single': cfg.ListOpt('list_opt_single',
+                                       default='1',
+                                       help='a list'),
+        'list_int_opt': cfg.ListOpt('list_int_opt',
+                                    default=[1, 2, 3],
+                                    help='a list'),
         'dict_opt': cfg.DictOpt('dict_opt',
                                 default={'1': 'yes', '2': 'no'},
                                 help='a dict'),
@@ -619,6 +625,28 @@ class GeneratorTestCase(base.BaseTestCase):
 
 # a list (list value)
 #list_opt = 1,2,3
+''')),
+        ('list_opt_single',
+         dict(opts=[('test', [(None, [opts['list_opt_single']])])],
+              expected='''[DEFAULT]
+
+#
+# From test
+#
+
+# a list (list value)
+#list_opt_single = 1
+''')),
+        ('list_int_opt',
+         dict(opts=[('test', [(None, [opts['list_int_opt']])])],
+              expected='''[DEFAULT]
+
+#
+# From test
+#
+
+# a list (list value)
+#list_int_opt = 1,2,3
 ''')),
         ('dict_opt',
          dict(opts=[('test', [(None, [opts['dict_opt']])])],
@@ -1553,10 +1581,10 @@ class GeneratorRaiseErrorTestCase(base.BaseTestCase):
         with mock.patch('pkg_resources.iter_entry_points', fake_eps):
             self.assertRaises(FakeException, generator.generate, self.conf)
 
-    def test_generator_call_with_no_arguments_raises_error(self):
+    def test_generator_call_with_no_arguments_raises_system_exit(self):
         testargs = ['oslo-config-generator']
         with mock.patch('sys.argv', testargs):
-            self.assertRaises(cfg.RequiredOptError, generator.main, [])
+            self.assertRaises(SystemExit, generator.main, [])
 
 
 class ChangeDefaultsTestCase(base.BaseTestCase):
